.. module:: enaml.widgets.mpl_canvas

========================
enaml.widgets.mpl_canvas
========================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    MPLCanvas


.. autoclass:: MPLCanvas
